% Usage:
%       out = asset_ff(params, y)
%   where
%       out    is a (2,2) matrix of the first order
%              derivatives of the static system residuals
%              columns correspond to endo variables in
%              the ordering as declared
%       params is a (4,1) vector of parameter values
%              in the ordering as declared
%       y      is a (2,1) vector of endogenous variables
%              in the ordering as declared
%
% Created by Dynare++ v. 1.3.5

% params ordering
% =====================
% theta
% rho
% bet
% xbar
%
% y ordering
% =====================
% y
% x

function out = asset_ff(params, y)
if size(y) ~= [2,1]
	error('Wrong size of y, must be [2,1]');
end
if size(params) ~= [4,1]
	error('Wrong size of params, must be [4,1]');
end

% hardwired constants
a0 =            0;
a1 =            1;
a2 = NaN;
a3 =    1.1283792;
% numerical constants
a11 =            1;
% parameter values
a6 = params(1); % theta
a17 = params(2); % rho
a5 = params(3); % bet
a19 = params(4); % xbar
% exogenous variables to zeros
a24 = 0.0; % e
% endogenous variables to y
a4 = y(1); % y
a12 = y(1); % y
a21 = y(2); % x
a16 = y(2); % x
a7 = y(2); % x

t13 = a11 + a12;
t8 = a6 * a7;
t9 = exp(t8);
t27 = a6 * t9;
t28 = a5 * t27;
t29 = t13 * t28;
t30 = -(t29);
t10 = a5 * t9;
t31 = -(t10);
t1 = a1;
t57 = -(a17);
% setting the output variable
out = zeros(2, 2);
out(1,2) = out(1,2) + t30; % x(1)
out(1,1) = out(1,1) + t31; % y(1)
out(1,1) = out(1,1) + t1; % y(0)
out(2,2) = out(2,2) + t1; % x(0)
out(2,2) = out(2,2) + t57; % x(-1)
